from distutils.core import setup
setup(
    name            = 'Cat_Alyst',
    version         = '1.0.0',
    py_modules      = ['Cat_Alyst'],
    author          = 'Cat_Alyst',
    author_email    = 'jl746@njit.edu',
    url             = 'http://www.headfirstlabs.com',
    description     = 'A simple test',
    )
